@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -174,4 +174,16 @@ public interface IStatementBuilder {
 	void buildWHERE(WHERE where);
 
     void buildList(LIST element);
+
+    void buildBitAND(BitAND bitAND);
+
+    void buildBitLSHIFT(BitLSHIFT bitLSHIFT);
+
+    void buildBitOR(BitOR bitOR);
+
+    void buildBitRSHIFT(BitRSHIFT bitRSHIFT);
+
+    void buildBitXOR(BitXOR bitXOR);
+
+    void buildINVERT(INVERT invert);
 }
