@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -68,10 +68,15 @@ public class UPDATE extends ModifyCommand {
 	    this(table.getName());
 	}
 
-	public void build(IStatementBuilder builder) {
+	@Override
+    public void build(IStatementBuilder builder) {
 		builder.buildUPDATE(this);
 	}
 	
+	public UPDATE SET(Column column, Expression expression) {
+	    return SET(column.getName(), expression);
+	}
+	
 	public UPDATE SET(String column, Expression expression) {
 		assignments.add(new Assignment(column, expression));
 		return this;
@@ -95,4 +100,4 @@ public class UPDATE extends ModifyCommand {
 	}
 
 
-}
\ No newline at end of file
+}
